@@ -592,6 +592,7 @@ static void interface_confirm_close(GtkWidget *btn,GdkEvent  *event, gpointer us
 		location_gpsd_control_stop(control);
 		map_view_stop(app_data->map_view);
 		osso_deinitialize(app_data->osso);
+	//	g_free(app_data);
 		gtk_main_quit();
 	}
 	  
@@ -650,6 +651,8 @@ static void interface_show_analyzer_view(
 	//navigation_menu_set_current_page(
 	//		app_data->navigation_menu,
 	//		app_data->analyzer_view_tab_id);
+	
+	app_data->analyzer_view->osso = app_data->osso;
 	app_data->analyzer_view->activity_state = app_data->map_view->activity_state;
 	
 	analyzer_view_show(app_data->analyzer_view);
